==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebDockManagerPointDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescription } from "./WebDockManagerPointDescription";
/**
 * @hidden
 */
var WebDockManagerPointDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDockManagerPointDescriptionMetadata, _super);
    function WebDockManagerPointDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerPointDescriptionMetadata.b = function (a) {
        if (WebDockManagerPointDescriptionMetadata.a == null) {
            WebDockManagerPointDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerPointDescriptionMetadata.c(WebDockManagerPointDescriptionMetadata.a);
        }
        if (a.k(WebDockManagerPointDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebDockManagerPointDescriptionMetadata.a);
    };
    WebDockManagerPointDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManagerPoint");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("X", "Number:double");
        a.item("Y", "Number:double");
    };
    WebDockManagerPointDescriptionMetadata.d = function (a) {
        WebDockManagerPointDescriptionMetadata.b(a);
        a.ad("WebDockManagerPoint", function () { return new WebDockManagerPointDescription(); });
        a.ac("WebDockManagerPoint", WebDockManagerPointDescriptionMetadata.a);
    };
    WebDockManagerPointDescriptionMetadata.$t = markType(WebDockManagerPointDescriptionMetadata, 'WebDockManagerPointDescriptionMetadata');
    WebDockManagerPointDescriptionMetadata.a = null;
    return WebDockManagerPointDescriptionMetadata;
}(Base));
export { WebDockManagerPointDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebDockManagerPointDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescription } from "./WebDockManagerPointDescription";
/**
 * @hidden
 */
var WebDockManagerPointDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDockManagerPointDescriptionMetadata, _super);
    function WebDockManagerPointDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerPointDescriptionMetadata.b = function (a) {
        if (WebDockManagerPointDescriptionMetadata.a == null) {
            WebDockManagerPointDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerPointDescriptionMetadata.c(WebDockManagerPointDescriptionMetadata.a);
        }
        if (a.k(WebDockManagerPointDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebDockManagerPointDescriptionMetadata.a);
    };
    WebDockManagerPointDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManagerPoint");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("X", "Number:double");
        a.item("Y", "Number:double");
    };
    WebDockManagerPointDescriptionMetadata.d = function (a) {
        WebDockManagerPointDescriptionMetadata.b(a);
        a.ae("WebDockManagerPoint", function () { return new WebDockManagerPointDescription(); });
        a.ad("WebDockManagerPoint", WebDockManagerPointDescriptionMetadata.a);
    };
    WebDockManagerPointDescriptionMetadata.$t = markType(WebDockManagerPointDescriptionMetadata, 'WebDockManagerPointDescriptionMetadata');
    WebDockManagerPointDescriptionMetadata.a = null;
    return WebDockManagerPointDescriptionMetadata;
}(Base));
export { WebDockManagerPointDescriptionMetadata };
